@@ -14,46 +14,21 @@
 #ifndef LLVM_CONFIG_H
 #define LLVM_CONFIG_H
 
-/* Installation directory for binary executables */
-/* #undef LLVM_BINDIR */
-
-/* Time at which LLVM was configured */
-/* #undef LLVM_CONFIGTIME */
-
-/* Installation directory for data files */
-/* #undef LLVM_DATADIR */
+/* Define if we link Polly to the tools */
+/* #undef LINK_POLLY_INTO_TOOLS */
 
 /* Target triple LLVM will generate code for by default */
 #define LLVM_DEFAULT_TARGET_TRIPLE "armv7l-unknown-linux-gnueabihf"
 
-/* Installation directory for documentation */
-/* #undef LLVM_DOCSDIR */
-
-/* Define if LLVM is built with asserts and checks that change the layout of
-   client-visible data structures.  */
-/* #undef LLVM_ENABLE_ABI_BREAKING_CHECKS */
-
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
 
-/* Installation directory for config files */
-/* #undef LLVM_ETCDIR */
-
 /* Has gcc/MSVC atomic intrinsics */
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
 #define LLVM_HOST_TRIPLE "armv7l-unknown-linux-gnueabihf"
 
-/* Installation directory for include files */
-/* #undef LLVM_INCLUDEDIR */
-
-/* Installation directory for .info files */
-/* #undef LLVM_INFODIR */
-
-/* Installation directory for man pages */
-/* #undef LLVM_MANDIR */
-
 /* LLVM architecture name for the native architecture, if available */
 #define LLVM_NATIVE_ARCH ARM
 
@@ -85,24 +60,21 @@
 #define LLVM_PREFIX "/usr"
 
 /* Define if we have the Intel JIT API runtime support library */
-/* #undef LLVM_USE_INTEL_JITEVENTS */
+#define LLVM_USE_INTEL_JITEVENTS 0
 
 /* Define if we have the oprofile JIT-support library */
-/* #undef LLVM_USE_OPROFILE */
+#define LLVM_USE_OPROFILE 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 3
+#define LLVM_VERSION_MAJOR 4
 
 /* Minor version of the LLVM API */
-#define LLVM_VERSION_MINOR 9
+#define LLVM_VERSION_MINOR 0
 
 /* Patch version of the LLVM API */
 #define LLVM_VERSION_PATCH 0
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "3.9.0"
-
-/* Define if we link Polly to the tools */
-/* #undef LINK_POLLY_INTO_TOOLS */
+#define LLVM_VERSION_STRING "4.0.0"
 
 #endif
